==> kreport-2.99.2.tar.xz: kreport-2.99.2/src/plugins/chart/KReportChartPlugin.h <==
/* This file is part of the KDE project
   Copyright (C) 2010 by Adam Pigg (adam@piggz.co.uk)

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#ifndef KREPORTCHARTPLUGIN_H
#define KREPORTCHARTPLUGIN_H

#include <KReportPluginInterface.h>

class KReportChartPlugin : public KReportPluginInterface
{
    Q_OBJECT
    public:
        explicit KReportChartPlugin(QObject *parent, const QVariantList &args = QVariantList());
        virtual ~KReportChartPlugin();

        virtual QObject* createRendererInstance(const QDomNode& element);
        virtual QObject* createDesignerInstance(const QDomNode& element, KoReportDesigner* , QGraphicsScene* scene);
        virtual QObject* createDesignerInstance(KoReportDesigner* , QGraphicsScene* scene, const QPointF& pos);
#ifdef KREPORT_SCRIPTING
        virtual QObject* createScriptInstance(KReportItemBase* item);
#endif
};

#endif // KOREPORTCHARTPLUGIN_H

==> kreport_3.1.0.orig.tar.xz: kreport-3.1.0/src/plugins/chart/KReportChartPlugin.h <==
/* This file is part of the KDE project
   Copyright (C) 2010 by Adam Pigg (adam@piggz.co.uk)

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#ifndef KREPORTCHARTPLUGIN_H
#define KREPORTCHARTPLUGIN_H

#include <KReportPluginInterface.h>

class KReportChartPlugin : public KReportPluginInterface
{
    Q_OBJECT
public:
    explicit KReportChartPlugin(QObject *parent, const QVariantList &args = QVariantList());
    virtual ~KReportChartPlugin();

    virtual QObject *createRendererInstance(const QDomNode &element);
    virtual QObject *createDesignerInstance(const QDomNode &element, KoReportDesigner *designer,
                                            QGraphicsScene *scene);
    virtual QObject *createDesignerInstance(KoReportDesigner *designer, QGraphicsScene *scene,
                                            const QPointF &pos);
#ifdef KREPORT_SCRIPTING
    virtual QObject *createScriptInstance(KReportItemBase *item);
#endif
};

#endif // KOREPORTCHARTPLUGIN_H
